@@ -8,9 +8,9 @@ use Log::ger;
 use App::orgadb::Common;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-03'; # DATE
+our $DATE = '2022-07-04'; # DATE
 our $DIST = 'App-orgadb'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 our %SPEC;
 
@@ -41,6 +41,22 @@ sub _select_addressbook_entries_single {
 
     my $res = [200, "OK", ""];
 
+    my $formatter;
+    if ($args{formatters} && @{ $args{formatters} }) {
+        my @filter_names;
+        for my $f (@{ $args{formatters} }) {
+            if ($f =~ /\A\[/) {
+                require JSON::PP;
+                $f = JSON::PP::decode_json($f);
+            }
+            push @filter_names, $f;
+        }
+        require Data::Sah::Filter;
+        $formatter = Data::Sah::Filter::gen_filter(
+            filter_names => \@filter_names,
+        );
+    }
+
     my @matching_entries;
     my ($re_category, $re_entry, $re_field);
   FIND_ENTRIES: {
@@ -80,6 +96,10 @@ sub _select_addressbook_entries_single {
                 class_prefixes => ["Org::Element"],
             }, $expr, $tree);
             push @matching_entries, @nodes;
+            if ($args{num_entries} && @matching_entries > $args{num_entries}) {
+                splice @matching_entries, $args{num_entries};
+                last FIND_ENTRIES;
+            }
         }
     } # FIND_ENTRIES
     log_trace "Number of matching entries: %d", scalar(@matching_entries);
@@ -127,6 +147,10 @@ sub _select_addressbook_entries_single {
                     class_prefixes => ["Org::Element"],
                 }, $expr_field, $entry);
 
+                if ($args{num_fields} && @matching_fields > $args{num_fields}) {
+                    splice @matching_fields, $args{num_fields};
+                }
+
                 next ENTRY unless @matching_fields;
             }
 
@@ -170,6 +194,7 @@ sub _select_addressbook_entries_single {
 
                     my $field_value = $field->children_as_string;
                     $field_value =~ s/\A\s+//s if $args{hide_field_name};
+                    $field_value = $formatter->($field_value) if $formatter;
                     $res->[2] .= $field_value;
                 }
             }
@@ -216,6 +241,8 @@ _
 sub select_addressbook_entries {
     my %args = @_;
 
+    return [400, "Please specify at least one file"] unless @{ $args{files} || [] };
+
     my $code_parse_files = sub {
         my @filenames = @_;
 
@@ -232,7 +259,16 @@ sub select_addressbook_entries {
                 $doc = $parser->parse(join "", <>);
             } else {
                 local $ENV{PERL_ORG_PARSER_CACHE} = $ENV{PERL_ORG_PARSER_CACHE} // 1;
-                $doc = $parser->parse_file($filename);
+                if ($filename =~ /\.gpg\z/) {
+                    require IPC::System::Options;
+                    my $content;
+                    IPC::System::Options::system(
+                        {log=>1, capture_stdout=>\$content, die=>1},
+                        "gpg", "-d", $filename);
+                    $doc = $parser->parse($content);
+                } else {
+                    $doc = $parser->parse_file($filename);
+                }
             }
             push @trees, $doc;
             push @tree_filenames, $filename;
@@ -271,7 +307,7 @@ App::orgadb - An opinionated Org addressbook tool
 
 =head1 VERSION
 
-This document describes version 0.003 of App::orgadb (from Perl distribution App-orgadb), released on 2022-07-03.
+This document describes version 0.004 of App::orgadb (from Perl distribution App-orgadb), released on 2022-07-04.
 
 =head1 SYNOPSIS
 
@@ -316,6 +352,24 @@ Find (sub)fields by string or regex search.
 
 Path to addressbook files.
 
+=item * B<formatters> => I<array[str]>
+
+Add one or more formatters to display field value.
+
+Specify one or more formatters to apply to the field value before displaying.
+
+A formatter is name of C<Data::Sah::Filter::perl::*> module, without the prefix.
+For example: C<Str::uc> will convert the field value to uppercase. Another
+formatter, C<Str::remove_comment> can remove comment.
+
+A formatter can have arguments, which is specified using this format:
+
+ [FORMATTER_NAME, {ARG1NAME => ARG1VAL, ...}]
+
+If formatter name begins with C<[> character, it will be parsed as JSON. Example:
+
+ ['Str::remove_comment', {'style':'cpp'}]
+
 =item * B<hide_category> => I<true>
 
 Do not show category.
@@ -328,6 +382,14 @@ Do not show entry headline.
 
 Do not show field names, just show field values.
 
+=item * B<num_entries> => I<uint>
+
+Specify maximum number of entries to return (0 means unlimited).
+
+=item * B<num_fields> => I<uint>
+
+Specify maximum number of fields (per entry) to return (0 means unlimited).
+
 =item * B<reload_files_on_change> => I<bool> (default: 1)
 
 =item * B<shell> => I<true>
