@@ -6,9 +6,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-03'; # DATE
+our $DATE = '2022-07-04'; # DATE
 our $DIST = 'App-orgadb'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 our %argspecs_common = (
     files => {
@@ -98,6 +98,42 @@ our %argspecs_select = (
         cmdline_aliases => {l=>{}},
         tags => ['category:display'],
     },
+    formatters => {
+        'x.name.is_plural' => 1,
+        'x.name.singular' => 'formatter',
+        summary => 'Add one or more formatters to display field value',
+        schema => ['array*', of=>'str*'],
+        tags => ['category:display'],
+        description => <<'_',
+
+Specify one or more formatters to apply to the field value before displaying.
+
+A formatter is name of `Data::Sah::Filter::perl::*` module, without the prefix.
+For example: `Str::uc` will convert the field value to uppercase. Another
+formatter, `Str::remove_comment` can remove comment.
+
+A formatter can have arguments, which is specified using this format:
+
+    [FORMATTER_NAME, {ARG1NAME => ARG1VAL, ...}]
+
+If formatter name begins with `[` character, it will be parsed as JSON. Example:
+
+ ['Str::remove_comment', {'style':'cpp'}]
+
+
+_
+    },
+
+    num_entries => {
+        summary => 'Specify maximum number of entries to return (0 means unlimited)',
+        schema => 'uint*',
+        tags => ['category:result'],
+    },
+    num_fields => {
+        summary => 'Specify maximum number of fields (per entry) to return (0 means unlimited)',
+        schema => 'uint*',
+        tags => ['category:result'],
+    },
 );
 
 1;
@@ -115,7 +151,7 @@ App::orgadb::Common
 
 =head1 VERSION
 
-This document describes version 0.003 of App::orgadb::Common (from Perl distribution App-orgadb), released on 2022-07-03.
+This document describes version 0.004 of App::orgadb::Common (from Perl distribution App-orgadb), released on 2022-07-04.
 
 =head1 HOMEPAGE
 
